@@ -80,6 +80,8 @@ static void         thunar_details_view_notify_model            (GtkTreeView
 static void         thunar_details_view_notify_width            (GtkTreeViewColumn      *tree_view_column,
                                                                  GParamSpec             *pspec,
                                                                  ThunarDetailsView      *details_view);
+static gboolean     thunar_details_view_column_header_clicked   (ThunarDetailsView      *details_view,
+                                                                 GdkEventButton         *event);
 static gboolean     thunar_details_view_button_press_event      (GtkTreeView            *tree_view,
                                                                  GdkEventButton         *event,
                                                                  ThunarDetailsView      *details_view);
@@ -135,7 +137,7 @@ struct _ThunarDetailsView
   /* whether the most recent item activation used a mouse button press */
   gboolean           button_pressed;
 
-  /* event source id for thunar_details_view_zoom_level_changed_reload_fixed_columns */
+  /* event source id for thunar_details_view_zoom_level_changed_reload_fixed_height */
   guint idle_id;
 
 };
@@ -279,7 +281,7 @@ thunar_details_view_init (ThunarDetailsView *details_view)
 
           /* add the name renderer */
           g_object_set (G_OBJECT (THUNAR_STANDARD_VIEW (details_view)->name_renderer),
-                        "xalign", 0.0, "ellipsize", PANGO_ELLIPSIZE_END, "width-chars", 30, NULL);
+                        "xalign", 0.0, "ellipsize", PANGO_ELLIPSIZE_END, "width-chars", 60, NULL);
           gtk_tree_view_column_pack_start (details_view->columns[column], THUNAR_STANDARD_VIEW (details_view)->name_renderer, TRUE);
           gtk_tree_view_column_set_attributes (details_view->columns[column], THUNAR_STANDARD_VIEW (details_view)->name_renderer,
                                                "text", THUNAR_COLUMN_NAME,
@@ -287,7 +289,6 @@ thunar_details_view_init (ThunarDetailsView *details_view)
 
           /* add some spacing between the icon and the name */
           gtk_tree_view_column_set_spacing (details_view->columns[column], 2);
-          gtk_tree_view_column_set_expand (details_view->columns[column], TRUE);
         }
       else
         {
@@ -326,6 +327,12 @@ thunar_details_view_init (ThunarDetailsView *details_view)
       for (column = 0; column < THUNAR_N_VISIBLE_COLUMNS; ++column)
         gtk_tree_view_column_set_fixed_width (details_view->columns[column], thunar_column_model_get_column_width (details_view->column_model, column));
     }
+  else
+    {
+      /* Make sure the name column auto-expands */
+      gtk_tree_view_column_set_fixed_width (details_view->columns[THUNAR_COLUMN_NAME],-1);
+      gtk_tree_view_column_set_expand (details_view->columns[THUNAR_COLUMN_NAME], TRUE);
+    }
 
   /* release the shared text renderers */
   g_object_unref (G_OBJECT (right_aligned_renderer));
@@ -630,6 +637,9 @@ thunar_details_view_notify_width (GtkTreeViewColumn *tree_view_column,
   _thunar_return_if_fail (GTK_IS_TREE_VIEW_COLUMN (tree_view_column));
   _thunar_return_if_fail (THUNAR_IS_DETAILS_VIEW (details_view));
 
+  /* for some reason gtk forgets the auto-expand state of the name column */
+  gtk_tree_view_column_set_expand (details_view->columns[THUNAR_COLUMN_NAME], !details_view->fixed_columns);
+
   /* lookup the column no for the given tree view column */
   for (column = 0; column < THUNAR_N_VISIBLE_COLUMNS; ++column)
     if (details_view->columns[column] == tree_view_column)
@@ -642,6 +652,28 @@ thunar_details_view_notify_width (GtkTreeViewColumn *tree_view_column,
 
 
 
+static gboolean
+thunar_details_view_column_header_clicked (ThunarDetailsView *details_view,
+                                           GdkEventButton    *event)
+{
+  GtkWidget *menu;
+
+  if (event->button == 3)
+    {
+      menu = gtk_menu_new ();
+      xfce_gtk_menu_item_new_from_action_entry (get_action_entry (THUNAR_DETAILS_VIEW_ACTION_CONFIGURE_COLUMNS), G_OBJECT (details_view), GTK_MENU_SHELL (menu));
+      gtk_widget_show_all (menu);
+
+      /* run the menu (takes over the floating of menu) */
+      thunar_gtk_menu_run (GTK_MENU (menu));
+      return TRUE;
+    }
+
+  return FALSE;
+}
+
+
+
 static gboolean
 thunar_details_view_button_press_event (GtkTreeView       *tree_view,
                                         GdkEventButton    *event,
@@ -654,7 +686,7 @@ thunar_details_view_button_press_event (GtkTreeView       *tree_view,
 
   /* check if the event is for the bin window */
   if (G_UNLIKELY (event->window != gtk_tree_view_get_bin_window (tree_view)))
-    return FALSE;
+    return thunar_details_view_column_header_clicked (details_view, event);
 
   /* get the current selection */
   selection = gtk_tree_view_get_selection (tree_view);
@@ -888,12 +920,13 @@ thunar_details_view_columns_changed (ThunarColumnModel *column_model,
 
 
 static gboolean
-thunar_details_view_zoom_level_changed_reload_fixed_columns (gpointer data)
+thunar_details_view_zoom_level_changed_reload_fixed_height (gpointer data)
 {
   ThunarDetailsView *details_view = data;
   _thunar_return_val_if_fail (THUNAR_IS_DETAILS_VIEW (details_view), FALSE);
 
-  thunar_details_view_set_fixed_columns (details_view, TRUE);
+  gtk_tree_view_set_fixed_height_mode (GTK_TREE_VIEW (gtk_bin_get_child (GTK_BIN (details_view))), TRUE);
+
   details_view->idle_id = 0;
   return FALSE;
 }
@@ -904,16 +937,14 @@ static void
 thunar_details_view_zoom_level_changed (ThunarDetailsView *details_view)
 {
   ThunarColumn column;
-  gboolean     fixed_columns_used = FALSE;
 
   _thunar_return_if_fail (THUNAR_IS_DETAILS_VIEW (details_view));
 
   if (details_view->fixed_columns == TRUE)
-    fixed_columns_used = TRUE;
-
-  /* Disable fixed column mode during resize, since it can generate graphical glitches */
-  if (fixed_columns_used)
-      thunar_details_view_set_fixed_columns (details_view, FALSE);
+    {
+      /* disable fixed_height_mode during resize, otherwise graphical glitches can appear*/
+      gtk_tree_view_set_fixed_height_mode (GTK_TREE_VIEW (gtk_bin_get_child (GTK_BIN (details_view))), FALSE);
+    }
 
   /* determine the list of tree view columns */
   for (column = 0; column < THUNAR_N_VISIBLE_COLUMNS; ++column)
@@ -922,10 +953,10 @@ thunar_details_view_zoom_level_changed (ThunarDetailsView *details_view)
       gtk_tree_view_column_queue_resize (details_view->columns[column]);
     }
 
-  if (fixed_columns_used)
+  if (details_view->fixed_columns == TRUE)
     {
       /* Call when idle to ensure that gtk_tree_view_column_queue_resize got finished */
-      details_view->idle_id = gdk_threads_add_idle (thunar_details_view_zoom_level_changed_reload_fixed_columns, details_view);
+      details_view->idle_id = gdk_threads_add_idle (thunar_details_view_zoom_level_changed_reload_fixed_height, details_view);
     }
 }
 
@@ -1061,6 +1092,7 @@ thunar_details_view_set_fixed_columns (ThunarDetailsView *details_view,
             {
               /* reset column to grow-only mode */
               gtk_tree_view_column_set_sizing (details_view->columns[column], GTK_TREE_VIEW_COLUMN_GROW_ONLY);
+              gtk_tree_view_column_set_fixed_width (details_view->columns[column],-1);
             }
         }
 
@@ -1069,6 +1101,14 @@ thunar_details_view_set_fixed_columns (ThunarDetailsView *details_view,
       if (fixed_columns)
         gtk_tree_view_set_fixed_height_mode (GTK_TREE_VIEW (gtk_bin_get_child (GTK_BIN (details_view))), TRUE);
 
+      if (fixed_columns == FALSE)
+        {
+          /* Make sure the name column auto-expands */
+          gtk_tree_view_column_set_expand (details_view->columns[THUNAR_COLUMN_NAME], TRUE);
+        }
+
+      gtk_tree_view_column_queue_resize (details_view->columns[THUNAR_COLUMN_NAME]);
+
       /* notify listeners */
       g_object_notify (G_OBJECT (details_view), "fixed-columns");
     }
