@@ -21,6 +21,7 @@
 #define __THUNAR_LIST_MODEL_H__
 
 #include <thunar/thunar-folder.h>
+#include <thunar/thunar-job.h>
 
 G_BEGIN_DECLS;
 
@@ -66,6 +67,9 @@ GList           *thunar_list_model_get_paths_for_pattern  (ThunarListModel  *sto
 
 gchar           *thunar_list_model_get_statusbar_text     (ThunarListModel  *store,
                                                            GList            *selected_items);
+ThunarJob       *thunar_list_model_get_job                (ThunarListModel  *store);
+void             thunar_list_model_set_job                (ThunarListModel  *store,
+                                                           ThunarJob        *job);
 
 G_END_DECLS;
 
