@@ -67,7 +67,6 @@ static void           thunar_location_buttons_set_current_directory       (Thuna
                                                                            ThunarFile                 *current_directory);
 static void           thunar_location_buttons_unmap                       (GtkWidget                  *widget);
 static void           thunar_location_buttons_on_filler_clicked           (ThunarLocationButtons      *buttons);
-static void           thunar_location_buttons_on_search_clicked           (ThunarLocationButtons      *buttons);
 static void           thunar_location_buttons_get_preferred_width         (GtkWidget                  *widget,
                                                                            gint                       *minimum,
                                                                            gint                       *natural);
@@ -141,7 +140,6 @@ struct _ThunarLocationButtons
   GtkWidget         *left_slider;
   GtkWidget         *right_slider;
   GtkWidget         *filler_widget;
-  GtkWidget         *search_widget;
 
   ThunarFile        *current_directory;
 
@@ -231,15 +229,6 @@ thunar_location_buttons_on_filler_clicked (ThunarLocationButtons *buttons)
 
 
 
-static void
-thunar_location_buttons_on_search_clicked (ThunarLocationButtons *buttons)
-{
-  GtkWidget *window = gtk_widget_get_toplevel (GTK_WIDGET (buttons));
-  thunar_window_action_search (THUNAR_WINDOW (window));
-}
-
-
-
 static void
 thunar_location_buttons_init (ThunarLocationButtons *buttons)
 {
@@ -281,17 +270,6 @@ thunar_location_buttons_init (ThunarLocationButtons *buttons)
   gtk_container_add (GTK_CONTAINER (buttons), buttons->filler_widget);
   gtk_widget_show (buttons->filler_widget);
 
-  buttons->search_widget = gtk_button_new ();
-  g_signal_connect_swapped (buttons->search_widget, "clicked", G_CALLBACK (thunar_location_buttons_on_search_clicked), buttons);
-
-  icon = gtk_image_new_from_icon_name ("system-search-symbolic", GTK_ICON_SIZE_BUTTON);
-  gtk_widget_set_halign (icon, GTK_ALIGN_END);
-  gtk_container_add (GTK_CONTAINER (buttons->search_widget), icon);
-  gtk_widget_show (icon);
-
-  gtk_container_add (GTK_CONTAINER (buttons), buttons->search_widget);
-  gtk_widget_show (buttons->search_widget);
-
   g_object_set (buttons, "valign", GTK_ALIGN_CENTER, NULL);
 
   /* setup style classes */
@@ -307,8 +285,6 @@ thunar_location_buttons_init (ThunarLocationButtons *buttons)
                                "path-bar-button");
   gtk_style_context_add_class (gtk_widget_get_style_context (GTK_WIDGET (buttons->filler_widget)),
                                "path-bar-button");
-  gtk_style_context_add_class (gtk_widget_get_style_context (GTK_WIDGET (buttons->search_widget)),
-                               "path-bar-button");
 
   buttons->launcher =  g_object_new (THUNAR_TYPE_LAUNCHER, "widget", GTK_WIDGET (buttons), NULL);
   g_signal_connect_swapped (G_OBJECT (buttons->launcher), "change-directory", G_CALLBACK (thunar_location_buttons_set_current_directory), buttons);
@@ -410,10 +386,10 @@ thunar_location_buttons_set_current_directory (ThunarNavigator *navigator,
   if (G_UNLIKELY (buttons->current_directory == current_directory))
     return;
 
-  /* check if we already have a button for that directory */
+  /* check if we already have a visible button for that directory */
   for (lp = buttons->list; lp != NULL; lp = lp->next)
     {
-      if (thunar_location_button_get_file (lp->data) == current_directory)
+      if (thunar_location_button_get_file (lp->data) == current_directory && gtk_widget_get_child_visible (GTK_WIDGET (lp->data)))
         {
           /* fake a "clicked" event for that button */
           gtk_button_clicked (GTK_BUTTON (lp->data));
@@ -554,7 +530,6 @@ thunar_location_buttons_get_path_for_child (GtkContainer *container,
         */
       visible_children = NULL;
       visible_children = g_list_prepend (visible_children, path_bar->right_slider);
-      visible_children = g_list_prepend (visible_children, path_bar->search_widget);
       visible_children = g_list_prepend (visible_children, path_bar->filler_widget);
 
       for (l = path_bar->list; l; l = l->next)
@@ -677,7 +652,6 @@ thunar_location_buttons_size_allocate (GtkWidget     *widget,
   GtkAllocation          folder_button_allocation;
   GtkAllocation          first_slider_allocation;  /* left slider if direction is LTR */
   GtkAllocation          second_slider_allocation; /* right slider if direction is LTR */
-  GtkAllocation          search_allocation;
   GtkAllocation          filler_allocation;
   GList                 *lp;
   gint                   required_width_total = 0;
@@ -705,25 +679,19 @@ thunar_location_buttons_size_allocate (GtkWidget     *widget,
   second_slider_allocation.height = available_space.height;
   second_slider_allocation.y = available_space.y;
 
-  search_allocation.width = buttons->slider_width;
-  search_allocation.height = available_space.height;
-  search_allocation.y = available_space.y;
-
   if (G_LIKELY (direction == GTK_TEXT_DIR_LTR))
     {
       first_slider_allocation.x = available_space.x;
       second_slider_allocation.x = available_space.x + available_space.width - buttons->slider_width;
-      search_allocation.x = available_space.x + available_space.width - buttons->slider_width - search_allocation.width;
     }
   else
     {
       first_slider_allocation.x = available_space.x + available_space.width - buttons->slider_width;
       second_slider_allocation.x = available_space.x;
-      search_allocation.x = available_space.x + buttons->slider_width;
     }
 
   gtk_widget_get_preferred_width (buttons->filler_widget, &filler_allocation.width, NULL);
-  required_width_total += buttons->slider_width * 2 + filler_allocation.width + search_allocation.width;
+  required_width_total += buttons->slider_width * 2 + filler_allocation.width;
   filler_allocation.height = available_space.height;
   filler_allocation.y = available_space.y;
 
@@ -747,7 +715,7 @@ thunar_location_buttons_size_allocate (GtkWidget     *widget,
   else
     {
       /* reset calculation for required_width_total .. we need to cut off some folders */
-      required_width_total = first_slider_allocation.width + second_slider_allocation.width + search_allocation.width + filler_allocation.width;
+      required_width_total = first_slider_allocation.width + second_slider_allocation.width + filler_allocation.width;
 
       /* No scrolling defined ? Use last button as fixed start! */
       if(buttons->last_visible_button == NULL && buttons->first_visible_button == NULL)
@@ -815,10 +783,8 @@ thunar_location_buttons_size_allocate (GtkWidget     *widget,
   /* allocate the sliders */
   gtk_widget_get_preferred_width (GTK_WIDGET (buttons->left_slider), &temp_width, NULL); //to dont get gtk warnings
   gtk_widget_get_preferred_width (GTK_WIDGET (buttons->right_slider), &temp_width, NULL);
-  gtk_widget_get_preferred_width (GTK_WIDGET (buttons->search_widget), &temp_width, NULL);
   gtk_widget_size_allocate (buttons->left_slider, &first_slider_allocation);
   gtk_widget_size_allocate (buttons->right_slider, &second_slider_allocation);
-  gtk_widget_size_allocate (buttons->search_widget, &search_allocation);
   thunar_location_buttons_update_sliders (buttons);
 
   if (need_reorder)
@@ -942,9 +908,6 @@ thunar_location_buttons_forall (GtkContainer *container,
 
   if (buttons->filler_widget != NULL && include_internals)
     (*callback) (buttons->filler_widget, callback_data);
-
-  if (buttons->filler_widget != NULL && include_internals)
-    (*callback) (buttons->search_widget, callback_data);
 }
 
 
