@@ -261,19 +261,19 @@ thunar_menu_add_sections (ThunarMenu         *menu,
       if (menu->type != THUNAR_MENU_TYPE_CONTEXT_TREE_VIEW && menu->type != THUNAR_MENU_TYPE_CONTEXT_SHORTCUTS_VIEW)
         item_added |= (thunar_launcher_append_menu_item (menu->launcher, GTK_MENU_SHELL (menu), THUNAR_LAUNCHER_ACTION_CREATE_DOCUMENT, force) != NULL);
       if (item_added)
-         xfce_gtk_menu_append_seperator (GTK_MENU_SHELL (menu));
+         xfce_gtk_menu_append_separator (GTK_MENU_SHELL (menu));
     }
 
   if (menu_sections & THUNAR_MENU_SECTION_OPEN)
     {
       if (thunar_launcher_append_open_section (menu->launcher, GTK_MENU_SHELL (menu), !menu->tab_support_disabled, !menu->change_directory_support_disabled, menu->force_section_open))
-         xfce_gtk_menu_append_seperator (GTK_MENU_SHELL (menu));
+         xfce_gtk_menu_append_separator (GTK_MENU_SHELL (menu));
     }
 
   if (menu_sections & THUNAR_MENU_SECTION_SENDTO)
     {
       if (thunar_launcher_append_menu_item (menu->launcher, GTK_MENU_SHELL (menu), THUNAR_LAUNCHER_ACTION_SENDTO_MENU, FALSE) != NULL)
-         xfce_gtk_menu_append_seperator (GTK_MENU_SHELL (menu));
+         xfce_gtk_menu_append_separator (GTK_MENU_SHELL (menu));
     }
 
   item_added = FALSE;
@@ -288,7 +288,7 @@ thunar_menu_add_sections (ThunarMenu         *menu,
         item_added |= (thunar_launcher_append_menu_item (menu->launcher, GTK_MENU_SHELL (menu), THUNAR_LAUNCHER_ACTION_PASTE, force) != NULL);
     }
   if (item_added)
-     xfce_gtk_menu_append_seperator (GTK_MENU_SHELL (menu));
+     xfce_gtk_menu_append_separator (GTK_MENU_SHELL (menu));
 
   if (menu_sections & THUNAR_MENU_SECTION_TRASH_DELETE)
     {
@@ -296,12 +296,12 @@ thunar_menu_add_sections (ThunarMenu         *menu,
       item_added |= (thunar_launcher_append_menu_item (menu->launcher, GTK_MENU_SHELL (menu), THUNAR_LAUNCHER_ACTION_MOVE_TO_TRASH, force) != NULL);
       item_added |= (thunar_launcher_append_menu_item (menu->launcher, GTK_MENU_SHELL (menu), THUNAR_LAUNCHER_ACTION_DELETE, force) != NULL);
       if (item_added)
-         xfce_gtk_menu_append_seperator (GTK_MENU_SHELL (menu));
+         xfce_gtk_menu_append_separator (GTK_MENU_SHELL (menu));
     }
   if (menu_sections & THUNAR_MENU_SECTION_EMPTY_TRASH)
     {
       if (thunar_launcher_append_menu_item (menu->launcher, GTK_MENU_SHELL (menu), THUNAR_LAUNCHER_ACTION_EMPTY_TRASH, FALSE) != NULL )
-         xfce_gtk_menu_append_seperator (GTK_MENU_SHELL (menu));
+         xfce_gtk_menu_append_separator (GTK_MENU_SHELL (menu));
     }
   if (menu_sections & THUNAR_MENU_SECTION_RESTORE)
     {
@@ -309,12 +309,12 @@ thunar_menu_add_sections (ThunarMenu         *menu,
       item_added |= (thunar_launcher_append_menu_item (menu->launcher, GTK_MENU_SHELL (menu), THUNAR_LAUNCHER_ACTION_RESTORE, FALSE) != NULL);
       item_added |= (thunar_launcher_append_menu_item (menu->launcher, GTK_MENU_SHELL (menu), THUNAR_LAUNCHER_ACTION_RESTORE_SHOW, FALSE) != NULL);
       if (item_added)
-        xfce_gtk_menu_append_seperator (GTK_MENU_SHELL (menu));
+        xfce_gtk_menu_append_separator (GTK_MENU_SHELL (menu));
     }
   if (menu_sections & THUNAR_MENU_SECTION_REMOVE_FROM_RECENT)
     {
       if (thunar_launcher_append_menu_item (menu->launcher, GTK_MENU_SHELL (menu), THUNAR_LAUNCHER_ACTION_REMOVE_FROM_RECENT, FALSE) != NULL)
-        xfce_gtk_menu_append_seperator (GTK_MENU_SHELL (menu));
+        xfce_gtk_menu_append_separator (GTK_MENU_SHELL (menu));
     }
 
   item_added = FALSE;
@@ -325,12 +325,12 @@ thunar_menu_add_sections (ThunarMenu         *menu,
   if (menu_sections & THUNAR_MENU_SECTION_RENAME)
     item_added |= (thunar_launcher_append_menu_item (menu->launcher, GTK_MENU_SHELL (menu), THUNAR_LAUNCHER_ACTION_RENAME, force) != NULL);
   if (item_added)
-     xfce_gtk_menu_append_seperator (GTK_MENU_SHELL (menu));
+     xfce_gtk_menu_append_separator (GTK_MENU_SHELL (menu));
 
   if (menu_sections & THUNAR_MENU_SECTION_CUSTOM_ACTIONS)
     {
       if (thunar_launcher_append_custom_actions (menu->launcher, GTK_MENU_SHELL (menu)))
-         xfce_gtk_menu_append_seperator (GTK_MENU_SHELL (menu));
+         xfce_gtk_menu_append_separator (GTK_MENU_SHELL (menu));
     }
 
   if (menu_sections & THUNAR_MENU_SECTION_MOUNTABLE)
@@ -340,7 +340,7 @@ thunar_menu_add_sections (ThunarMenu         *menu,
       item_added |= (thunar_launcher_append_menu_item (menu->launcher, GTK_MENU_SHELL (menu), THUNAR_LAUNCHER_ACTION_UNMOUNT, FALSE) != NULL);
       item_added |= (thunar_launcher_append_menu_item (menu->launcher, GTK_MENU_SHELL (menu), THUNAR_LAUNCHER_ACTION_EJECT, FALSE) != NULL);
       if (item_added)
-         xfce_gtk_menu_append_seperator (GTK_MENU_SHELL (menu));
+         xfce_gtk_menu_append_separator (GTK_MENU_SHELL (menu));
     }
 
   if (menu_sections & THUNAR_MENU_SECTION_ZOOM)
@@ -351,7 +351,7 @@ thunar_menu_add_sections (ThunarMenu         *menu,
           thunar_window_append_menu_item (THUNAR_WINDOW (window), GTK_MENU_SHELL (menu), THUNAR_WINDOW_ACTION_ZOOM_IN);
           thunar_window_append_menu_item (THUNAR_WINDOW (window), GTK_MENU_SHELL (menu), THUNAR_WINDOW_ACTION_ZOOM_OUT);
           thunar_window_append_menu_item (THUNAR_WINDOW (window), GTK_MENU_SHELL (menu), THUNAR_WINDOW_ACTION_ZOOM_RESET);
-          xfce_gtk_menu_append_seperator (GTK_MENU_SHELL (menu));
+          xfce_gtk_menu_append_separator (GTK_MENU_SHELL (menu));
         }
     }
 
