@@ -22,6 +22,8 @@
 #endif
 
 #include <libxfce4ui/libxfce4ui.h>
+#include <libxfce4kbd-private-3/libxfce4kbd-private/xfce-shortcuts-editor.h>
+#include <libxfce4kbd-private-3/libxfce4kbd-private/xfce-shortcuts-editor-dialog.h>
 
 #include <thunar/thunar-compact-view.h>
 #include <thunar/thunar-details-view.h>
@@ -35,6 +37,10 @@
 #include <thunar/thunar-preferences.h>
 #include <thunar/thunar-private.h>
 #include <thunar/thunar-util.h>
+#include <thunar/thunar-window.h>
+#include <thunar/thunar-shortcuts-view.h>
+#include <thunar/thunar-renamer-dialog.h>
+#include <thunar/thunar-statusbar.h>
 
 
 
@@ -512,7 +518,7 @@ thunar_preferences_dialog_init (ThunarPreferencesDialog *dialog)
   gtk_box_pack_start (GTK_BOX (vbox), frame, FALSE, TRUE, 0);
   gtk_widget_show (frame);
 
-  label = gtk_label_new (_("Window icon"));
+  label = gtk_label_new (_("Window Icon"));
   gtk_label_set_attributes (GTK_LABEL (label), thunar_pango_attr_list_bold ());
   gtk_frame_set_label_widget (GTK_FRAME (frame), label);
   gtk_widget_show (label);
@@ -592,7 +598,7 @@ thunar_preferences_dialog_init (ThunarPreferencesDialog *dialog)
                                         "%H hour\n"
                                         "%M minute\n"
                                         "%S second\n\n"
-                                        "For a complete list, check the man pages of 'strftime'"));
+                                        "For a complete list, search 'Glib.DateTime.format'."));
   g_object_bind_property (G_OBJECT (dialog->preferences),
                           "misc-date-custom-style",
                           G_OBJECT (entry),
@@ -647,6 +653,8 @@ thunar_preferences_dialog_init (ThunarPreferencesDialog *dialog)
   gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (combo), _("160px"));
   gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (combo), _("192px"));
   gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (combo), _("256px"));
+  gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (combo), _("512px"));
+  gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (combo), _("1024px"));
   g_object_bind_property_full (G_OBJECT (dialog->preferences),
                                "shortcuts-icon-size",
                                G_OBJECT (combo),
@@ -711,6 +719,8 @@ thunar_preferences_dialog_init (ThunarPreferencesDialog *dialog)
   gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (combo), _("160px"));
   gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (combo), _("192px"));
   gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (combo), _("256px"));
+  gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (combo), _("512px"));
+  gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (combo), _("1024px"));
   g_object_bind_property_full (G_OBJECT (dialog->preferences),
                                "tree-icon-size",
                                G_OBJECT (combo),
@@ -895,6 +905,32 @@ thunar_preferences_dialog_init (ThunarPreferencesDialog *dialog)
   /* next row */
   row++;
 
+  button = gtk_check_button_new_with_mnemonic (_("Show full directory paths in tab titles"));
+  g_object_bind_property (G_OBJECT (dialog->preferences),
+                          "misc-full-path-in-tab-title",
+                          G_OBJECT (button),
+                          "active",
+                          G_BINDING_BIDIRECTIONAL | G_BINDING_SYNC_CREATE);
+  gtk_widget_set_tooltip_text (button, _("Select this option to show the full directory path in the tab title instead of only the directory name"));
+  gtk_grid_attach (GTK_GRID (grid), button, 0, row, 1, 1);
+  gtk_widget_show (button);
+
+  /* next row */
+  row++;
+
+  button = gtk_check_button_new_with_mnemonic (_("Split panes vertically instead of horizontally"));
+  g_object_bind_property (G_OBJECT (dialog->preferences),
+                          "misc-vertical-split-pane",
+                          G_OBJECT (button),
+                          "active",
+                          G_BINDING_BIDIRECTIONAL | G_BINDING_SYNC_CREATE);
+  gtk_widget_set_tooltip_text (button, _("Select this option to split panes vertically instead of horizontally."));
+  gtk_grid_attach (GTK_GRID (grid), button, 0, row, 1, 1);
+  gtk_widget_show (button);
+
+  /* next row */
+  row++;
+
   button = gtk_check_button_new_with_mnemonic (_("Open new thunar instances as tabs"));
   g_object_bind_property (G_OBJECT (dialog->preferences),
                           "misc-open-new-window-as-tab",
@@ -971,7 +1007,7 @@ thunar_preferences_dialog_init (ThunarPreferencesDialog *dialog)
   gtk_box_pack_start (GTK_BOX (vbox), frame, FALSE, TRUE, 0);
   gtk_widget_show (frame);
 
-  label = gtk_label_new (_("File transfer"));
+  label = gtk_label_new (_("File Transfer"));
   gtk_label_set_attributes (GTK_LABEL (label), thunar_pango_attr_list_bold ());
   gtk_frame_set_label_widget (GTK_FRAME (frame), label);
   gtk_widget_show (label);
@@ -1247,6 +1283,28 @@ thunar_preferences_dialog_init (ThunarPreferencesDialog *dialog)
       gtk_container_add (GTK_CONTAINER (frame), infobar);
     }
 
+  /*
+   Shortcuts
+  */
+  label = gtk_label_new (_("Shortcuts"));
+  vbox = g_object_new (GTK_TYPE_BOX, "orientation", GTK_ORIENTATION_VERTICAL, "border-width", 12, "spacing", 18, NULL);
+  gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox, label);
+  gtk_widget_show (label);
+  gtk_widget_show (vbox);
+
+  frame = g_object_new (GTK_TYPE_FRAME, "border-width", 0, "shadow-type", GTK_SHADOW_IN, NULL);
+  gtk_box_pack_start (GTK_BOX (vbox), frame, FALSE, TRUE, 0);
+  gtk_widget_show (frame);
+
+  grid = xfce_shortcuts_editor_new (13,
+                                    _("Window"), thunar_window_get_action_entries (), THUNAR_WINDOW_N_ACTIONS,
+                                    _("View"), thunar_standard_view_get_action_entries (), THUNAR_STANDARD_VIEW_N_ACTIONS,
+                                    _("Launcher"), thunar_launcher_get_action_entries (), THUNAR_LAUNCHER_N_ACTIONS,
+                                    _("Status Bar"), thunar_statusbar_get_action_entries (), THUNAR_STATUS_BAR_N_ACTIONS
+                                    );
+  gtk_container_add (GTK_CONTAINER (frame), grid);
+  gtk_widget_show (grid);
+
   /* cleanup */
   g_free (path);
 }
