@@ -78,6 +78,8 @@ enum
   PROP_LAST_WINDOW_HEIGHT,
   PROP_LAST_WINDOW_WIDTH,
   PROP_LAST_WINDOW_FULLSCREEN,
+  PROP_LAST_TOOLBAR_VISIBLE_BUTTONS,
+  PROP_LAST_TOOLBAR_BUTTON_ORDER,
   PROP_MISC_DIRECTORY_SPECIFIC_SETTINGS,
   PROP_MISC_ALWAYS_SHOW_TABS,
   PROP_MISC_VOLUME_MANAGEMENT,
@@ -86,7 +88,8 @@ enum
   PROP_MISC_DATE_CUSTOM_STYLE,
   PROP_EXEC_SHELL_SCRIPTS_BY_DEFAULT,
   PROP_MISC_FOLDERS_FIRST,
-  PROP_MISC_FULL_PATH_IN_TITLE,
+  PROP_MISC_FULL_PATH_IN_TAB_TITLE,
+  PROP_MISC_FULL_PATH_IN_WINDOW_TITLE,
   PROP_MISC_HORIZONTAL_WHEEL_NAVIGATES,
   PROP_MISC_IMAGE_SIZE_IN_STATUSBAR,
   PROP_MISC_MIDDLE_CLICK_IN_TAB,
@@ -115,6 +118,7 @@ enum
   PROP_TREE_ICON_EMBLEMS,
   PROP_TREE_ICON_SIZE,
   PROP_MISC_SWITCH_TO_NEW_TAB,
+  PROP_MISC_VERTICAL_SPLIT_PANE,
   N_PROPERTIES,
 };
 
@@ -434,6 +438,30 @@ thunar_preferences_class_init (ThunarPreferencesClass *klass)
                             FALSE,
                             EXO_PARAM_READWRITE);
 
+  /**
+   * ThunarPreferences:last-toolbar-visible-buttons:
+   *
+   * The comma separated list that specifies the visibility of toolbar items.
+   **/
+    preferences_props[PROP_LAST_TOOLBAR_VISIBLE_BUTTONS] =
+        g_param_spec_string ("last-toolbar-visible-buttons",
+                             "LastToolbarVisibleButtons",
+                             NULL,
+                             "1,1,1,1,0,0,0,1,0,1",
+                             EXO_PARAM_READWRITE);
+
+  /**
+   * ThunarPreferences:last-toolbar-button-order:
+   *
+   * The comma separated list that specifies the order of toolbar items.
+   **/
+    preferences_props[PROP_LAST_TOOLBAR_BUTTON_ORDER] =
+        g_param_spec_string ("last-toolbar-item-order",
+                             "LastToolbarButtonOrder",
+                             NULL,
+                             "0,1,2,3,4,5,6,7,8,9",
+                             EXO_PARAM_READWRITE);
+
   /**
    * ThunarPreferences:misc-directory-specific-settings:
    *
@@ -640,14 +668,27 @@ thunar_preferences_class_init (ThunarPreferencesClass *klass)
                             EXO_PARAM_READWRITE);
 
   /**
-   * ThunarPreferences:misc-full-path-in-title:
+   * ThunarPreferences:misc-full-path-in-tab-title:
+   *
+   * Show the full directory path in the tab title, instead of
+   * only the directory name.
+   **/
+  preferences_props[PROP_MISC_FULL_PATH_IN_TAB_TITLE] =
+      g_param_spec_boolean ("misc-full-path-in-tab-title",
+                            "MiscFullPathInTabTitle",
+                            NULL,
+                            FALSE,
+                            EXO_PARAM_READWRITE);
+
+  /**
+   * ThunarPreferences:misc-full-path-in-window-title:
    *
    * Show the full directory path in the window title, instead of
    * only the directory name.
    **/
-  preferences_props[PROP_MISC_FULL_PATH_IN_TITLE] =
-      g_param_spec_boolean ("misc-full-path-in-title",
-                            "MiscFullPathInTitle",
+  preferences_props[PROP_MISC_FULL_PATH_IN_WINDOW_TITLE] =
+      g_param_spec_boolean ("misc-full-path-in-window-title",
+                            "MiscFullPathInWindowTitle",
                             NULL,
                             FALSE,
                             EXO_PARAM_READWRITE);
@@ -1021,6 +1062,21 @@ thunar_preferences_class_init (ThunarPreferencesClass *klass)
                             TRUE,
                             EXO_PARAM_READWRITE);
 
+
+
+  /**
+   * ThunarPreferences:misc-vertical-split-pane
+   *
+   * If true, split the thunar window vertically instead of horizontally
+   * when splitting the thunar window into two panes.
+   **/
+  preferences_props[PROP_MISC_VERTICAL_SPLIT_PANE] =
+    g_param_spec_boolean ("misc-vertical-split-pane",
+                          "MiscVerticalSplitPane",
+                          NULL,
+                          FALSE,
+                          EXO_PARAM_READWRITE);
+
   /* install all properties */
   g_object_class_install_properties (gobject_class, N_PROPERTIES, preferences_props);
 }
