@@ -35,6 +35,7 @@
 
 #include <exo/exo.h>
 #include <libxfce4ui/libxfce4ui.h>
+#include <libxfce4util/libxfce4util.h>
 
 #include <thunar/thunar-abstract-dialog.h>
 #include <thunar/thunar-application.h>
@@ -1262,6 +1263,7 @@ thunar_properties_dialog_update_single (ThunarPropertiesDialog *dialog)
 
   /* cleanup */
   g_object_unref (G_OBJECT (icon_factory));
+  g_free (date_custom_style);
 }
 
 
