@@ -91,10 +91,10 @@ static void        thunar_renamer_dialog_response              (GtkDialog
 static void        thunar_renamer_dialog_context_menu          (ThunarRenamerDialog      *renamer_dialog);
 static void        thunar_renamer_dialog_help                  (ThunarRenamerDialog      *renamer_dialog);
 static void        thunar_renamer_dialog_save                  (ThunarRenamerDialog      *renamer_dialog);
-static void        thunar_renamer_dialog_action_add_files      (ThunarRenamerDialog      *renamer_dialog);
-static void        thunar_renamer_dialog_action_remove_files   (ThunarRenamerDialog      *renamer_dialog);
-static void        thunar_renamer_dialog_action_clear          (ThunarRenamerDialog      *renamer_dialog);
-static void        thunar_renamer_dialog_action_about          (ThunarRenamerDialog      *renamer_dialog);
+static gboolean    thunar_renamer_dialog_action_add_files      (ThunarRenamerDialog      *renamer_dialog);
+static gboolean    thunar_renamer_dialog_action_remove_files   (ThunarRenamerDialog      *renamer_dialog);
+static gboolean    thunar_renamer_dialog_action_clear          (ThunarRenamerDialog      *renamer_dialog);
+static gboolean    thunar_renamer_dialog_action_about          (ThunarRenamerDialog      *renamer_dialog);
 static void        thunar_renamer_dialog_name_column_clicked   (GtkTreeViewColumn        *column,
                                                                 ThunarRenamerDialog      *renamer_dialog);
 static gboolean    thunar_renamer_dialog_button_press_event    (GtkWidget                *tree_view,
@@ -518,7 +518,7 @@ thunar_renamer_dialog_init (ThunarRenamerDialog *renamer_dialog)
       gtk_container_add (GTK_CONTAINER (button), image);
       gtk_widget_show (image);
 
-      /* create the name/suffix/both combo box */
+      /* create the name/extension/both combo box */
       mcombo = gtk_combo_box_text_new ();
       klass = g_type_class_ref (THUNAR_TYPE_RENAMER_MODE);
       active_str = xfce_rc_read_entry_untranslated (rc, "LastActiveMode", "");
@@ -915,12 +915,12 @@ thunar_renamer_dialog_context_menu (ThunarRenamerDialog *renamer_dialog)
           for(lp = items; lp != NULL; lp = lp->next)
               thunar_gtk_menu_thunarx_menu_item_new (lp->data, GTK_MENU_SHELL (menu));
           g_list_free (items);
-          xfce_gtk_menu_append_seperator (GTK_MENU_SHELL (menu));
+          xfce_gtk_menu_append_separator (GTK_MENU_SHELL (menu));
         }
     }
   thunar_renamer_dialog_append_menu_item (renamer_dialog, GTK_MENU_SHELL (menu), THUNAR_RENAMER_ACTION_ADD_FILES);
   thunar_renamer_dialog_append_menu_item (renamer_dialog, GTK_MENU_SHELL (menu), THUNAR_RENAMER_ACTION_REMOVE_FILES);
-  xfce_gtk_menu_append_seperator (GTK_MENU_SHELL (menu));
+  xfce_gtk_menu_append_separator (GTK_MENU_SHELL (menu));
   thunar_menu_add_sections (menu, THUNAR_MENU_SECTION_PROPERTIES);
   thunar_menu_hide_accel_labels (menu);
   gtk_widget_show_all (GTK_WIDGET (menu));
@@ -1055,7 +1055,7 @@ trd_video_filter_func (const GtkFileFilterInfo *info,
 
 
 
-static void
+static gboolean
 thunar_renamer_dialog_action_add_files (ThunarRenamerDialog *renamer_dialog)
 {
   GtkFileFilter *filter;
@@ -1065,7 +1065,7 @@ thunar_renamer_dialog_action_add_files (ThunarRenamerDialog *renamer_dialog)
   GSList        *lp;
   gchar         *uri;
 
-  _thunar_return_if_fail (THUNAR_IS_RENAMER_DIALOG (renamer_dialog));
+  _thunar_return_val_if_fail (THUNAR_IS_RENAMER_DIALOG (renamer_dialog), FALSE);
 
   /* allocate the file chooser */
   chooser = gtk_file_chooser_dialog_new (_("Select files to rename"),
@@ -1155,11 +1155,14 @@ thunar_renamer_dialog_action_add_files (ThunarRenamerDialog *renamer_dialog)
 
   /* cleanup */
   gtk_widget_destroy (chooser);
+
+  /* required in case of shortcut activation, in order to signal that the accel key got handled */
+  return TRUE;
 }
 
 
 
-static void
+static gboolean
 thunar_renamer_dialog_action_remove_files (ThunarRenamerDialog *renamer_dialog)
 {
   GtkTreeRowReference *row;
@@ -1169,7 +1172,7 @@ thunar_renamer_dialog_action_remove_files (ThunarRenamerDialog *renamer_dialog)
   GList               *rows;
   GList               *lp;
 
-  _thunar_return_if_fail (THUNAR_IS_RENAMER_DIALOG (renamer_dialog));
+  _thunar_return_val_if_fail (THUNAR_IS_RENAMER_DIALOG (renamer_dialog), FALSE);
 
   /* determine the selected rows in the view */
   selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (renamer_dialog->tree_view));
@@ -1200,30 +1203,39 @@ thunar_renamer_dialog_action_remove_files (ThunarRenamerDialog *renamer_dialog)
 
   /* cleanup */
   g_list_free (rows);
+
+  /* required in case of shortcut activation, in order to signal that the accel key got handled */
+  return TRUE;
 }
 
 
 
-static void
+static gboolean
 thunar_renamer_dialog_action_clear (ThunarRenamerDialog *renamer_dialog)
 {
-  _thunar_return_if_fail (THUNAR_IS_RENAMER_DIALOG (renamer_dialog));
+  _thunar_return_val_if_fail (THUNAR_IS_RENAMER_DIALOG (renamer_dialog), FALSE);
 
   /* just clear the list of files in the model */
   thunar_renamer_model_clear (renamer_dialog->model);
+
+  /* required in case of shortcut activation, in order to signal that the accel key got handled */
+  return TRUE;
 }
 
 
 
-static void
+static gboolean
 thunar_renamer_dialog_action_about (ThunarRenamerDialog *renamer_dialog)
 {
-  _thunar_return_if_fail (THUNAR_IS_RENAMER_DIALOG (renamer_dialog));
+  _thunar_return_val_if_fail (THUNAR_IS_RENAMER_DIALOG (renamer_dialog), FALSE);
 
   /* just popup the about dialog */
   thunar_dialogs_show_about (GTK_WINDOW (renamer_dialog), _("Bulk Rename"),
                              _("Thunar Bulk Rename is a powerful and extensible\n"
                                "tool to rename multiple files at once."));
+
+  /* required in case of shortcut activation, in order to signal that the accel key got handled */
+  return TRUE;
 }
 
 
