@@ -33,6 +33,8 @@
 
 #include <gdk/gdkkeysyms.h>
 
+#include <libxfce4util/libxfce4util.h>
+
 #include <thunar/thunar-navigator.h>
 #include <thunar/thunar-application.h>
 #include <thunar/thunar-browser.h>
@@ -123,11 +125,11 @@ static void           thunar_shortcuts_view_context_menu                 (Thunar
                                                                           GdkEventButton           *event,
                                                                           GtkTreeModel             *model,
                                                                           GtkTreeIter              *iter);
-static void           thunar_shortcuts_view_remove_activated             (ThunarShortcutsView      *view,
+static gboolean       thunar_shortcuts_view_remove_activated             (ThunarShortcutsView      *view,
                                                                           GtkWidget                *item);
 static void           thunar_shortcuts_view_editing_canceled             (GtkCellRenderer          *renderer,
                                                                           ThunarShortcutsView      *view);
-static void           thunar_shortcuts_view_rename_activated             (ThunarShortcutsView      *view,
+static gboolean       thunar_shortcuts_view_rename_activated             (ThunarShortcutsView      *view,
                                                                           GtkWidget                *item);
 static void           thunar_shortcuts_view_renamed                      (GtkCellRenderer          *renderer,
                                                                           const gchar              *path_string,
@@ -1251,7 +1253,7 @@ thunar_shortcuts_view_context_menu (ThunarShortcutsView *view,
           thunar_launcher_append_menu_item (view->launcher, GTK_MENU_SHELL (context_menu), THUNAR_LAUNCHER_ACTION_OPEN, TRUE);
           thunar_launcher_append_menu_item (view->launcher, GTK_MENU_SHELL (context_menu), THUNAR_LAUNCHER_ACTION_OPEN_IN_TAB, TRUE);
           thunar_launcher_append_menu_item (view->launcher, GTK_MENU_SHELL (context_menu), THUNAR_LAUNCHER_ACTION_OPEN_IN_WINDOW, TRUE);
-          xfce_gtk_menu_append_seperator (GTK_MENU_SHELL (context_menu));
+          xfce_gtk_menu_append_separator (GTK_MENU_SHELL (context_menu));
           thunar_menu_add_sections (context_menu, THUNAR_MENU_SECTION_EMPTY_TRASH);
         }
       else
@@ -1279,7 +1281,7 @@ thunar_shortcuts_view_context_menu (ThunarShortcutsView *view,
       thunar_launcher_append_menu_item (view->launcher, GTK_MENU_SHELL (context_menu), THUNAR_LAUNCHER_ACTION_OPEN, TRUE);
       thunar_launcher_append_menu_item (view->launcher, GTK_MENU_SHELL (context_menu), THUNAR_LAUNCHER_ACTION_OPEN_IN_TAB, TRUE);
       thunar_launcher_append_menu_item (view->launcher, GTK_MENU_SHELL (context_menu), THUNAR_LAUNCHER_ACTION_OPEN_IN_WINDOW, TRUE);
-      xfce_gtk_menu_append_seperator (GTK_MENU_SHELL (context_menu));
+      xfce_gtk_menu_append_separator (GTK_MENU_SHELL (context_menu));
       thunar_menu_add_sections (context_menu, THUNAR_MENU_SECTION_MOUNTABLE);
       if (thunar_device_is_mounted (device))
         thunar_menu_add_sections (context_menu, THUNAR_MENU_SECTION_PROPERTIES);
@@ -1289,7 +1291,7 @@ thunar_shortcuts_view_context_menu (ThunarShortcutsView *view,
 
   if (group == THUNAR_SHORTCUT_GROUP_PLACES_BOOKMARKS)
   {
-      xfce_gtk_menu_append_seperator (GTK_MENU_SHELL (context_menu));
+      xfce_gtk_menu_append_separator (GTK_MENU_SHELL (context_menu));
       item = xfce_gtk_menu_item_new_from_action_entry (get_action_entry (THUNAR_SHORTCUTS_VIEW_ACTION_REMOVE_BOOKMARK), G_OBJECT (model), GTK_MENU_SHELL (context_menu));
       g_object_set_data_full (G_OBJECT (item), I_("thunar-shortcuts-row"),
                               gtk_tree_row_reference_new (model, path),
@@ -1319,7 +1321,7 @@ thunar_shortcuts_view_context_menu (ThunarShortcutsView *view,
 
 
 
-static void
+static gboolean
 thunar_shortcuts_view_remove_activated (ThunarShortcutsView *view,
                                         GtkWidget           *item)
 {
@@ -1339,6 +1341,9 @@ thunar_shortcuts_view_remove_activated (ThunarShortcutsView *view,
       thunar_shortcuts_model_remove (THUNAR_SHORTCUTS_MODEL (child_model), child_path);
       gtk_tree_path_free (child_path);
     }
+
+  /* required in case of shortcut activation, in order to signal that the accel key got handled */
+  return TRUE;
 }
 
 
@@ -1356,7 +1361,7 @@ thunar_shortcuts_view_editing_canceled (GtkCellRenderer     *renderer,
 
 
 
-static void
+static gboolean
 thunar_shortcuts_view_rename_activated (ThunarShortcutsView *view,
                                         GtkWidget           *item)
 {
@@ -1389,6 +1394,9 @@ thunar_shortcuts_view_rename_activated (ThunarShortcutsView *view,
       gtk_tree_path_free (path);
       g_list_free (renderers);
     }
+
+  /* required in case of shortcut activation, in order to signal that the accel key got handled */
+  return TRUE;
 }
 
 
