@@ -307,7 +307,7 @@ thunar_tree_model_init (ThunarTreeModel *model)
   /* allocate the "virtual root node" */
   model->root = g_node_new (NULL);
 
-  /* inititalize references to certain toplevel nodes */
+  /* initialize references to certain toplevel nodes */
   model->file_system = NULL;
   model->network = NULL;
 
@@ -1110,8 +1110,7 @@ thunar_tree_model_device_added (ThunarDeviceMonitor *device_monitor,
       if (item->device == NULL)
         break;
 
-      /* sort devices by timestamp */
-      if (thunar_device_sort (item->device, device) > 0)
+      if (thunar_device_compare_by_name (item->device, device) > 0)
         break;
     }
 
