@@ -63,6 +63,7 @@ typedef enum
   THUNAR_WINDOW_ACTION_TOGGLE_SIDE_PANE,
   THUNAR_WINDOW_ACTION_VIEW_STATUSBAR,
   THUNAR_WINDOW_ACTION_VIEW_MENUBAR,
+  THUNAR_WINDOW_ACTION_CONFIGURE_TOOLBAR,
   THUNAR_WINDOW_ACTION_SHOW_HIDDEN,
   THUNAR_WINDOW_ACTION_ZOOM_IN,
   THUNAR_WINDOW_ACTION_ZOOM_IN_ALT_1,
@@ -99,6 +100,7 @@ typedef enum
   THUNAR_WINDOW_ACTION_SEARCH,
   THUNAR_WINDOW_ACTION_CANCEL_SEARCH,
 
+  THUNAR_WINDOW_N_ACTIONS
 } ThunarWindowAction;
 
 GType                     thunar_window_get_type                            (void) G_GNUC_CONST;
@@ -144,9 +146,18 @@ void                      thunar_window_open_files_in_location              (Thu
 void                      thunar_window_show_and_select_files               (ThunarWindow        *window,
                                                                              GList               *files_to_select);
 void                      thunar_window_update_search                       (ThunarWindow        *window);
-void                      thunar_window_action_cancel_search                (ThunarWindow        *window);
-void                      thunar_window_action_search                       (ThunarWindow        *window);
+gboolean                  thunar_window_action_cancel_search                (ThunarWindow        *window);
+gboolean                  thunar_window_action_search                       (ThunarWindow        *window);
 void                      thunar_window_update_statusbar                    (ThunarWindow        *window);
+void                      thunar_window_toolbar_toggle_item_visibility      (ThunarWindow        *window,
+                                                                             gint                 index);
+void                      thunar_window_toolbar_swap_items                  (ThunarWindow        *window,
+                                                                             gint                 index_a,
+                                                                             gint                 index_b);
+
+XfceGtkActionEntry*       thunar_window_get_action_entries                  (void);
+
+void                      thunar_window_reconnect_accelerators              (ThunarWindow        *window);
 
 
 G_END_DECLS;
